# Project Metadata

::: harborapi.client.HarborAsyncClient
    options:
        members:
        - get_project_metadata
        - set_project_metadata
        - get_project_metadata_entry
        - update_project_metadata_entry
        - delete_project_metadata_entry
